@@ -40,6 +40,10 @@ private slots:
   void gotoPrevKeyset();
   void gotoNextKeyset();
 
+  void on_autoSearchButton_pressed();
+
+  void on_pauseSearchButton_pressed();
+
 private:
   bool checkMutex();
 
