@@ -9,8 +9,10 @@ class BekoTV1: public PIRKeysetMetaData
 {
 public:
   BekoTV1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // BEKO_H
