@@ -244,7 +244,7 @@ PIRKeysetManager::PIRKeysetManager()
 
   setupKeyset(new DellRemote1(++counter));
 
-  setupKeyset(new DeutscheTelekomSTB1(++counter));
+//  setupKeyset(new DeutscheTelekomSTB1(++counter));
 
   setupKeyset(new DigitalStreamReceiver(++counter));
 
