@@ -25,6 +25,7 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Daewoo_Make] = "Daewoo";
   makes[Dell_Make] = "Dell";
   makes[Denon_Make] = "Denon";
+  makes[DeutscheTelekom_Make] = "Deutsche Telekom";
   makes[DigitalStream_Make] = "Digital Stream";
   makes[Directv_Make] = "DirecTV";
   makes[Dish_Make] = "Dish";
@@ -34,12 +35,14 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Ei_Make] = "Ei";
   makes[Elgato_Make] = "Elgato";
   makes[Emerson_Make] = "Emerson";
+  makes[Emtec_Make] = "Emtec";
   makes[Epson_Make] = "Epson";
   makes[Fortec_Make] = "Fortec Star";
   makes[Foxtel_Make] = "Foxtel";
   makes[Gadmei_Make] = "Gadmei";
   makes[Genius_Make] = "Genius";
   makes[GoldStar_Make] = "GoldStar";
+  makes[Goodmans_Make] = "Goodmans";
   makes[Grundig_Make] = "Grundig";
   makes[Haier_Make] = "Haier";
   makes[HarmanKardon_Make] = "Harman/Kardon";
@@ -67,12 +70,15 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Mitsubishi_Make] = "Mitsubishi";
   makes[Motorola_Make] = "Motorola";
   makes[NAD_Make] = "NAD";
+  makes[Nikon_Make] = "Nikon";
   makes[Nokia_Make] = "Nokia";
   makes[Octagon_Make] = "Octagon";
+  makes[Olympus_Make] = "Olympus";
   makes[Onida_Make] = "Onida";
   makes[Onkyo_Make] = "Onkyo";
   makes[Orion_Make] = "Orion";
   makes[Panasonic_Make] = "Panasonic";
+  makes[Pentax_Make] = "Pentax";
   makes[Philco_Make] = "Philco";
   makes[Philips_Make] = "Philips";
   makes[Pinnacle_Make] = "Pinnacle Systems";
