@@ -142,6 +142,26 @@ bool PIRSelectKeysetForm::selectPrevKeyset()
 }
 
 
+bool PIRSelectKeysetForm::selectFirstKeyset()
+{
+  if (ui->keysetListWidget->count() == 0)
+  {
+    return false;
+  }
+
+  if (ui->keysetListWidget->currentRow() != 0)
+  {
+    ui->keysetListWidget->setCurrentRow(
+      0, QItemSelectionModel::ClearAndSelect);
+
+    mainWindow->keysetSelectionChanged(
+      ui->keysetListWidget->currentItem());
+  }
+
+  return true;
+}
+
+
 QString PIRSelectKeysetForm::getKeysetName()
 {
   QListWidgetItem *item = ui->keysetListWidget->currentItem();
